==> fltk-docs-1.3.8-1.0-i686.pkg.tar.zst: usr/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK 1.3.8", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcafaf89941b05600b6d4513e387d69cd36",
"classFl.html#a43e6e0bbbc03cad134d928d4edd48d1da2344bf14f80ecf5971e8aa4493a3858a",
"classFl__Color__Chooser.html#a267e63ddf0d5d1f03074d7d4339ba1fe",
"classFl__Graphics__Driver.html#a0b9590d3bc415c0cdb2ba2fb6dc589ad",
"classFl__Image.html#a64dbb6fe30e3080a24f718231b371a17",
"classFl__Pack.html#a8820c6b4dba2209ab4b650b3a04cde05",
"classFl__Printer.html#a82f5d6a0fe67c6b756251c6c2f470010",
"classFl__Table.html#a8f83d61e9c7ec6d19a49ad1ae1eb6ffc",
"classFl__Text__Display.html#af2d8e613a81bfea815288b9d77874b4b",
"classFl__Tree__Item.html#a64eabbcb09b56c83455866dbce18cc0c",
"classFl__Widget.html#a454a0be4839ea5ed2aa203d788bf840f",
"editor.html#editor_copy_cb",
"functions_b.html",
"gl_8h.html#a2409bd4d2cc30153fefc8f9da51c0cdd",
"globals_l.html",
"group__fl__drawings.html#ga6f6f1aea3b90a03c1714336e7aef349d",
"intro.html#intro_licensing",
"structFl__Text__Editor_1_1Key__Binding.html#ab9b34380e32d84f35c000e29250349c9"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> fltk-docs-1.3.9-1.0-i686.pkg.tar.zst: usr/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK 1.3.9", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bcafaf89941b05600b6d4513e387d69cd36",
"classFl.html#a43e6e0bbbc03cad134d928d4edd48d1da01d530d6bc747eb0c192038eb802a8bd",
"classFl__Color__Chooser.html",
"classFl__Graphics__Driver.html",
"classFl__Image.html#a330a1e329253dd923e2a4380f705c583",
"classFl__PNM__Image.html#a27249eef602a3d5be4adc6bbcd6f13ad",
"classFl__Printer.html#a2b49948772a2fbe2d7a849ead465c36a",
"classFl__Table.html#a82b1a353a6d0345e6714fb7d3a2ae0ac",
"classFl__Text__Display.html#ae925f0bbfe42a6dc649a1fac85c13dee",
"classFl__Tree__Item.html#a5b02fa934ba1700ae845d4f13e824195",
"classFl__Widget.html#a3eb3b128cbad3f579a66cab813470442",
"drawing.html#ssect_Offscreen",
"forms.html#forms_importing",
"group__fl__drawings.html#ga0670c9917da81b4fe67da44fd4fb4ab7",
"group__group__comdlg.html#ga1be4def8585ff443bf26d676b3040baa",
"structFl__Menu__Item.html#aedb0508adf79fcb6c917b5eacb2601d5"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
